package controller

import (
	"github.com/gin-gonic/gin"
	"iot_manager_service/app/device/dao"
	"iot_manager_service/app/device/model"
	"iot_manager_service/app/device/service"
	"iot_manager_service/util"
	"math"
	"net/http"
	"strconv"
)

// 智慧网关基本信息管理对象
var WisdomGateway = new(wisdomGatewayCtl)

type wisdomGatewayCtl struct{}

func (c *wisdomGatewayCtl) Detail(ctx *gin.Context) {
	id, e := strconv.Atoi(ctx.Query("id"))
	if e != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(e.Error(), nil))
		return
	}

	device, err := service.GatewayService.Get(id)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, device))
}

func (c *wisdomGatewayCtl) List(ctx *gin.Context) {
	searchValue := ctx.Query("searchValue")
	current, _ := strconv.Atoi(ctx.Query("current"))
	size, _ := strconv.Atoi(ctx.Query("size"))
	if current == 0 {
		current = 1
	}
	if size <= 0 || size > 100 {
		size = 10
	}

	devices, err := service.GatewayService.List(searchValue, current, size)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	pages := math.Ceil(float64(len(devices)) / float64(size))
	rsp := model.RspGatewayList{
		Current: current,
		Size:    size,
		Total:   len(devices),
		Pages:   int(pages),
		Records: devices,
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, rsp))
}

func (c *wisdomGatewayCtl) CreateOrUpdate(ctx *gin.Context) {
	var req *model.GatewayDetail
	if err := ctx.ShouldBindJSON(&req); err != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(err.Error(), nil))
		return
	}
	err := service.GatewayService.CreateOrUpdate(req)
	ctx.JSON(http.StatusOK, err)
}

func (c *wisdomGatewayCtl) Remove(ctx *gin.Context) {
	var req *model.ReqGatewayRemove
	if err := ctx.ShouldBindJSON(&req); err != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(err.Error(), nil))
		return
	}
	err := service.GatewayService.Remove(req.IDs)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, nil))
}

func (c *wisdomGatewayCtl) ImportExcel(ctx *gin.Context) {
}

func (c *wisdomGatewayCtl) ExportExcel(ctx *gin.Context) {
}

func (c *wisdomGatewayCtl) ExportTemplate(ctx *gin.Context) {
}

func (c *wisdomGatewayCtl) GetList(ctx *gin.Context) {
	devices, err := service.GatewayService.GetList()
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, devices))
}

func (c *wisdomGatewayCtl) GetRelevanceDetail(ctx *gin.Context) {
	id, e := strconv.Atoi(ctx.Query("id"))
	if e != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(e.Error(), nil))
		return
	}

	device, err := service.GatewayService.GetRelevanceDetail(id)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, device))
}

func gatewayDaoToModel(device dao.Gateway) model.GatewayDetail {
	return model.GatewayDetail{
		Gateway:           device,
		CountLampPole:     0,
		EndLineTime:       "",
		NetworkState:      "",
		RunState:          "",
		Cpu:               "",
		Memory:            "",
		AlarmTerminalList: nil,
		CameraList:        nil,
		CaptureUnitList:   nil,
		InfoBoardList:     nil,
		IpBroadcastList:   nil,
		LightControlList:  nil,
		ZigbeeList:        nil,
		OptoSensorList:    nil,
	}
}
